@@ -2,6 +2,9 @@ from __future__ import absolute_import, print_function, division
 import numpy as np
 
 MAGIC = u"HDF5::Cooler"
+MAGIC_SCOOL = u"HDF5::SCOOL"
+MAGIC_MCOOL = u"HDF5::MCOOL"
+
 URL = u"https://github.com/mirnylab/cooler"
 CHROM_DTYPE = np.dtype("S")
 CHROMID_DTYPE = np.int32
@@ -28,4 +31,4 @@ from ._ingest import (
     ContactBinner,
 )
 
-from ._create import create_cooler, create, create_from_unordered, append, rename_chroms
+from ._create import create_cooler, create, create_from_unordered, append, rename_chroms, create_scool
